<?php

namespace Bixo\Conveyancing\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\Conveyancing\Actions\ContactAction;
use Bixo\Conveyancing\Http\Requests\ContactActionRequest;
use Bixo\Conveyancing\Http\Resources\ContactResource;
use Bixo\Conveyancing\Models\Contact;

/**
 * Admin web controller class.
 */
class ContactActionController extends BaseController
{

    /**
     * Action controller function for contact.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(ContactActionRequest $request, Contact $contact, $action)
    {
        try {
            $request = $request->all();
            $contact = ContactAction::run($action, $contact, $request);

            $data = new ContactResource($contact);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('conveyancing::contact.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('conveyancing/contact/' . $contact->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('conveyancing/contact/' . $contact->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
