<?php

namespace Bixo\Conveyancing\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\Conveyancing\Actions\ConveyancingAction;
use Bixo\Conveyancing\Http\Requests\ConveyancingActionRequest;
use Bixo\Conveyancing\Http\Resources\ConveyancingResource;
use Bixo\Conveyancing\Models\Conveyancing;

/**
 * Admin web controller class.
 */
class ConveyancingActionController extends BaseController
{

    /**
     * Action controller function for conveyancing.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(ConveyancingActionRequest $request, Conveyancing $conveyancing, $action)
    {
        try {
            $request = $request->all();
            $conveyancing = ConveyancingAction::run($action, $conveyancing, $request);

            $data = new ConveyancingResource($conveyancing);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('conveyancing::conveyancing.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('conveyancing/conveyancing/' . $conveyancing->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('conveyancing/conveyancing/' . $conveyancing->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
