<?php

namespace Bixo\Conveyancing\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Bixo\Conveyancing\Http\Resources\ConveyancingResource;
use Bixo\Conveyancing\Http\Resources\ConveyancingsCollection;
use Bixo\Conveyancing\Scopes\ConveyancingPublicScope;
use Bixo\Conveyancing\Models\Conveyancing;

class ConveyancingPublicController extends BaseController
{

    /**
     * Show conveyancing's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Conveyancing::pushScope(new RequestScope())
            ->pushScope(new ConveyancingPublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $conveyancings = new ConveyancingsCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('conveyancing::conveyancing.names'))
            ->view('conveyancing::public.conveyancing.index')
            ->data(compact('conveyancings', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show conveyancing.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Conveyancing::findBySlug($slug);
        $data = new ConveyancingResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('conveyancing::conveyancing.name'))
            ->view('conveyancing::public.conveyancing.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
