<?php

namespace Bixo\Conveyancing\Http\Controllers;

use Exception;
use Litepie\Http\Controllers\ResourceController as BaseController;
use Bixo\Conveyancing\Forms\Conveyancing as ConveyancingForm;
use Bixo\Conveyancing\Http\Requests\ConveyancingResourceRequest;
use Bixo\Conveyancing\Http\Resources\ConveyancingResource;
use Bixo\Conveyancing\Http\Resources\ConveyancingsCollection;
use Bixo\Conveyancing\Models\Conveyancing;
use Bixo\Conveyancing\Actions\ConveyancingAction;
use Bixo\Conveyancing\Actions\ConveyancingActions;


/**
 * Resource controller class for conveyancing.
 */
class ConveyancingResourceController extends BaseController
{

    /**
     * Initialize conveyancing resource controller.
     *
     *
     * @return null
     */
    public function __construct()
    {
        parent::__construct();
        $this->middleware(function ($request, $next) {
            $this->form = ConveyancingForm::grouped(false)
                            ->setAttributes()
                            ->toArray();
            $this->modules = $this->modules(config('bixo.conveyancing.modules'), 'conveyancing', guard_url('conveyancing'));
            return $next($request);
        });
    }

    /**
     * Display a list of conveyancing.
     *
     * @return Response
     */
    public function index(ConveyancingResourceRequest $request)
    {
        $request = $request->all();
        $page = ConveyancingActions::run('paginate', $request);

        $data = new ConveyancingsCollection($page);

        $form = $this->form;
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('conveyancing::conveyancing.names'))
            ->view('conveyancing::conveyancing.index')
            ->data(compact('data', 'modules', 'form'))
            ->output();

    }

    /**
     * Display conveyancing.
     *
     * @param Request $request
     * @param Model   $conveyancing
     *
     * @return Response
     */
    public function show(ConveyancingResourceRequest $request, Conveyancing $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new ConveyancingResource($model);
        return $this->response
            ->setMetaTitle(trans('app.view') . ' ' . trans('conveyancing::conveyancing.name'))
            ->data(compact('data', 'form', 'modules'))
            ->view('conveyancing::conveyancing.show')
            ->output();
    }

    /**
     * Show the form for creating a new conveyancing.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ConveyancingResourceRequest $request, Conveyancing $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new ConveyancingResource($model);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('conveyancing::conveyancing.name'))
            ->view('conveyancing::conveyancing.create')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Create new conveyancing.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ConveyancingResourceRequest $request, Conveyancing $model)
    {
        try {
            $request = $request->all();
            $model = ConveyancingAction::run('store', $model, $request);
            $data = new ConveyancingResource($model);
            return $this->response->message(trans('messages.success.created', ['Module' => trans('conveyancing::conveyancing.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('conveyancing/conveyancing/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/conveyancing/conveyancing'))
                ->redirect();
        }

    }

    /**
     * Show conveyancing for editing.
     *
     * @param Request $request
     * @param Model   $conveyancing
     *
     * @return Response
     */
    public function edit(ConveyancingResourceRequest $request, Conveyancing $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new ConveyancingResource($model);
        // return view('conveyancing::conveyancing.edit', compact('data', 'form', 'modules'));

        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('conveyancing::conveyancing.name'))
            ->view('conveyancing::conveyancing.edit')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Update the conveyancing.
     *
     * @param Request $request
     * @param Model   $conveyancing
     *
     * @return Response
     */
    public function update(ConveyancingResourceRequest $request, Conveyancing $model)
    {
        try {
            $request = $request->all();
            $model = ConveyancingAction::run('update', $model, $request);
            $data = new ConveyancingResource($model);

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('conveyancing::conveyancing.name')]))
                ->code(204)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('conveyancing/conveyancing/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('conveyancing/conveyancing/' .  $model->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the conveyancing.
     *
     * @param Model   $conveyancing
     *
     * @return Response
     */
    public function destroy(ConveyancingResourceRequest $request, Conveyancing $model)
    {
        try {

            $request = $request->all();
            $model = ConveyancingAction::run('destroy', $model, $request);
            $data = new ConveyancingResource($model);

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('conveyancing::conveyancing.name')]))
                ->code(202)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('conveyancing/conveyancing/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('conveyancing/conveyancing/' .  $model->getRouteKey()))
                ->redirect();
        }

    }
}
