<?php

namespace Bixo\Conveyancing\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Conveyancing\Events\ConveyancingAction as ConveyancingActionEvent;
use Bixo\Conveyancing\Notifications\ConveyancingAction as ConveyancingActionNotification;
use Litepie\Actions\Concerns\AsAction;

class ConveyancingAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the ConveyancingActionEvent.
     *
     * @param   ConveyancingActionEvent  $event
     * @return mixed
     */
    public function handle(ConveyancingActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $conveyancing.
     *
     * @param   ConveyancingActionEvent  $event
     * @return void
     */
    public function create(ConveyancingActionEvent $event)
    {
        $client = $event->conveyancing->client;
        Notification::send($client, new ConveyancingActionNotification($event));
    }

    /**
     * Handle the ConveyancingActionEvent as a listener.
     *
     * @param   ConveyancingActionEvent  $event
     * @return mixed
     */
    public function asListener(ConveyancingActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   ConveyancingActionEvent  $event
     * @return bool
     */
    private function isAllowed(ConveyancingActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
