<?php

namespace Bixo\Conveyancing\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Conveyancing\Events\ConveyancingWorkflow as ConveyancingWorkflowEvent;
use Bixo\Conveyancing\Notifications\ConveyancingWorkflow as ConveyancingWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class ConveyancingWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(ConveyancingWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $conveyancing is submitted.
     *
     * @param ConveyancingWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(ConveyancingWorkflowEvent $event)
    {
        $client = $event->conveyancing->client;
        Notification::send($client, new ConveyancingWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $conveyancing is published.
     *
     * @param ConveyancingWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(ConveyancingWorkflowEvent $event)
    {
        $client = $event->conveyancing->client;
        Notification::send($client, new ConveyancingWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $conveyancing is approved.
     *
     * @param ConveyancingWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(ConveyancingWorkflowEvent $event)
    {
        $client = $event->conveyancing->client;
        Notification::send($client, new ConveyancingWorkflowNotification($event));
    }

    /**
     * Handles the $conveyancing workflow event as a listener.
     *
     * @param ConveyancingWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(ConveyancingWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
