<?php
namespace Bixo\Conveyancing\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Bixo\Conveyancing\Events\ContactAction as ContactActionEvent;
use Bixo\Conveyancing\Models\Contact;

class ContactAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $contact;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param ContactActionEvent $contact
     */
    public function __construct(ContactActionEvent $contact)
    {
        $this->action = $event->action;
        $this->contact = $contact;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Contact Approved - ' . config('app.name'))
            ->view('conveyancing::contact.email.action', ['data' => $this->contact]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
