<?php
namespace Bixo\Conveyancing\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Bixo\Conveyancing\Events\ConveyancingAction as ConveyancingActionEvent;
use Bixo\Conveyancing\Models\Conveyancing;

class ConveyancingAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $conveyancing;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param ConveyancingActionEvent $conveyancing
     */
    public function __construct(ConveyancingActionEvent $conveyancing)
    {
        $this->action = $event->action;
        $this->conveyancing = $conveyancing;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Conveyancing Approved - ' . config('app.name'))
            ->view('conveyancing::conveyancing.email.action', ['data' => $this->conveyancing]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
