<?php

namespace Bixo\Conveyancing\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Conveyancing\Models\Conveyancing;

class ConveyancingPolicy
{

    use ConveyancingAction;
    use ConveyancingReport;
    use ConveyancingWorkflow;

    /**
     * Determine if the given user can view the conveyancing.
     *
     * @param Authenticatable $user
     * @param Conveyancing $conveyancing
     *
     * @return bool
     */
    public function view(Authenticatable $user, Conveyancing $conveyancing)
    {
        if ($authUser->canDo('conveyancing.conveyancing.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $conveyancing->is_owner;
    }

    /**
     * Determine if the given user can create a conveyancing.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('conveyancing.conveyancing.create');
    }

    /**
     * Determine if the given user can update the given conveyancing.
     *
     * @param Authenticatable $user
     * @param Conveyancing $conveyancing
     *
     * @return bool
     */
    public function update(Authenticatable $user, Conveyancing $conveyancing)
    {
        if ($user->canDo('conveyancing.conveyancing.edit') && $user->isAdmin()) {
            return true;
        }

        return $conveyancing->is_owner;
    }

    /**
     * Determine if the given user can delete the given conveyancing.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Conveyancing $conveyancing)
    {
        return $conveyancing->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
