<?php

namespace Bixo\Conveyancing\Providers;

use Illuminate\Support\ServiceProvider;
use Bixo\Conveyancing\Conveyancings;

class ConveyancingServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'conveyancing');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'conveyancing');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();

        $this->app->register(\Bixo\Conveyancing\Providers\AuthServiceProvider::class);
        $this->app->register(\Bixo\Conveyancing\Providers\RouteServiceProvider::class);
        $this->app->register(\Bixo\Conveyancing\Providers\ActionServiceProvider::class);
        $this->app->register(\Bixo\Conveyancing\Providers\EventServiceProvider::class);
        $this->app->register(\Bixo\Conveyancing\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('bixo.conveyancing', function($app)
        {
            return $this->app->make(Conveyancing::class);
        });
    }

    /**
     * Merges user's and conveyancing's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'bixo.conveyancing'
        );
        
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/conveyancing.php', 'bixo.conveyancing.conveyancing'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/contact.php', 'bixo.conveyancing.contact'
        );
    }


    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['bixo.conveyancing'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/' => config_path('bixo/conveyancing')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/conveyancing')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/conveyancing')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
